@@ -43,6 +43,7 @@ var StandardFunctions = map[string]KeyBuilderFunction{
 
 	// Comparisons
 	"if":     KeyBuilderFunction(kfIf),
+	"switch": kfSwitch,
 	"unless": KeyBuilderFunction(kfUnless),
 	"eq": stringComparator(func(a, b string) string {
 		if a == b {
@@ -65,6 +66,7 @@ var StandardFunctions = map[string]KeyBuilderFunction{
 	"or":  KeyBuilderFunction(kfOr),
 
 	// Strings
+	"len":    KeyBuilderFunction(kfLen),
 	"like":   KeyBuilderFunction(kfLike),
 	"prefix": KeyBuilderFunction(kfPrefix),
 	"suffix": KeyBuilderFunction(kfSuffix),
@@ -80,6 +82,7 @@ var StandardFunctions = map[string]KeyBuilderFunction{
 
 	// Ranges
 	"@":       kfJoin(ArraySeparator),
+	"@len":    kfArrayLen,
 	"@map":    kfArrayMap,
 	"@split":  kfArraySplit,
 	"@select": kfArraySelect,
@@ -94,6 +97,11 @@ var StandardFunctions = map[string]KeyBuilderFunction{
 	"dirname":  kfPathDir,
 	"extname":  kfPathExt,
 
+	// File operations
+	"load":   kfLoadFile,
+	"lookup": kfLookupKey,
+	"haskey": kfHasKey,
+
 	// Formatting
 	"hi":      KeyBuilderFunction(kfHumanizeInt),
 	"hf":      KeyBuilderFunction(kfHumanizeFloat),
